@@ -53,4 +53,10 @@ sub num_coupons {
     return scalar @{ $results->{coupon} };
 }
 
+sub num_payments {
+    my $self = shift;
+    my $results = shift;
+    return scalar @{ $results->{payments} };
+}
+
 1
